# clamav-client

`clamav-client` is a portable Python module to use the ClamAV anti-virus engine
on  Windows, Linux, MacOSX and other platforms. It requires a running instance
of  the `clamd` daemon.

This is a fork of [clamd] ([5c5e33b2]) created by Thomas Grainger.


[clamd]: https://github.com/graingert/python-clamd
[5c5e33b2]: https://github.com/graingert/python-clamd/commit/5c5e33b2dfd0499470e15abeb83efb6531ef9ab7
